<?php namespace Config;

// Create a new instance of our RouteCollection class.
$routes = Services::routes(true);

// Load the system's routing file first, so that the app and ENVIRONMENT
// can override as needed.
if (file_exists(SYSTEMPATH . 'Config/Routes.php'))
{
	require SYSTEMPATH . 'Config/Routes.php';
}

/**
 * --------------------------------------------------------------------
 * Router Setup
 * --------------------------------------------------------------------
 */
$routes->setDefaultNamespace('App\Controllers');

$routes->setTranslateURIDashes(false);
$routes->set404Override();
$routes->setAutoRoute(true);

/**
 * --------------------------------------------------------------------
 * Route Definitions
 * --------------------------------------------------------------------
 */

// We get a performance increase by specifying the default
// route since we don't have to scan directories.
$routes->get('/mobile/categories', 'Mobile::categories');
$routes->get('/mobile/links', 'Mobile::links');
$routes->get('/mobile/streams/(:num)', 'Mobile::streams/$1');
$routes->match(['get','post'],'/admin/signin', 'Admins::login', ['filter' => 'noauth']);
$routes->get('/admin/logout', 'Admins::logout');
$routes->match(['get','post'],'/admin/profile', 'Admins::profile',['filter' => 'auth']);
$routes->get('/admin/dashboard', 'Admins::index',['filter' => 'auth']);

$routes->get('/admin/categories', 'Admins::categories',['filter' => 'auth']);
$routes->match(['get','post'],'/admin/categories/add', 'Admins::addCategory',['filter' => 'auth']);
$routes->match(['get','post'],'/admin/categories/edit/(:num)', 'Admins::editCategory/$1',['filter' => 'auth']);

$routes->match(['get','post'],'/admin/categories/delete/(:num)', 'Admins::deleteCategory/$1',['filter' => 'auth']);

$routes->match(['get'],'/category/(:any)', 'Home::category/$1');

$routes->match(['get','post'],'/admin/bitcoin', 'Admins::bitcoin',['filter' => 'auth']);
$routes->match(['get','post'],'/admin/paypal', 'Admins::paypal',['filter' => 'auth']);
$routes->get('/admin/games', 'Admins::games',['filter' => 'auth']);
$routes->match(['get'],'/admin/game/delete/(:num)', 'Admins::deleteGame/$1',['filter' => 'auth']);
$routes->match(['get'],'/admin/game/postpone/(:num)', 'Admins::postponeGame/$1',['filter' => 'auth']);
$routes->match(['get'],'/admin/game/makeitlive/(:num)', 'Admins::makeitlive/$1',['filter' => 'auth']);
$routes->match(['get','post'],'/admin/game/edit/(:any)', 'Admins::editGame/$1',['filter' => 'auth']);

$routes->match(['get','post'],'/admin/games/add', 'Admins::addGames',['filter' => 'auth']);


$routes->match(['get','post'],'/admin/messages/home', 'Admins::homeMessage',['filter' => 'auth']);
$routes->match(['get','post'],'/admin/messages/category', 'Admins::categoryMessage',['filter' => 'auth']);
$routes->match(['get','post'],'/admin/messages/stream', 'Admins::streamMessage',['filter' => 'auth']);

$routes->match(['get','post'],'/admin/share', 'Admins::share',['filter' => 'auth']);
$routes->match(['get'],'/', 'Home::index');
$routes->match(['get'],'/(:any)', 'Home::stream/$1');

/**
 * --------------------------------------------------------------------
 * Additional Routing
 * --------------------------------------------------------------------
 *
 * There will often be times that you need additional routing and you
 * need to it be able to override any defaults in this file. Environment
 * based routes is one such time. require() additional route files here
 * to make that happen.
 *
 * You will have access to the $routes object within that file without
 * needing to reload it.
 */
if (file_exists(APPPATH . 'Config/' . ENVIRONMENT . '/Routes.php'))
{
	require APPPATH . 'Config/' . ENVIRONMENT . '/Routes.php';
}
